@@ -791,6 +791,37 @@ void GraphicsContext::fillRoundedRect(const IntRect& rect, const IntSize& topLef
     p->fillPath(path.platformPath(), QColor(color));
 }
 
+void GraphicsContext::fillRectWithRoundedHole(const IntRect& rect, const RoundedRect& roundedHoleRect, const Color& color, ColorSpace colorSpace)
+{
+    if (paintingDisabled() || !color.isValid())
+        return;
+
+    Path path;
+    path.addRect(rect);
+    if (!roundedHoleRect.radii().isZero())
+        path.addRoundedRect(roundedHoleRect);
+    else
+        path.addRect(roundedHoleRect.rect());
+
+    QPainterPath platformPath = path.platformPath();
+    platformPath.setFillRule(Qt::OddEvenFill);
+
+    QPainter* p = m_data->p();
+    if (hasShadow()) {
+        ShadowBlur* shadow = shadowBlur();
+        if (shadow->mustUseShadowBlur(this))
+            shadow->drawInsetShadow(this, rect, roundedHoleRect.rect(), roundedHoleRect.radii());
+        else {
+            const QPointF shadowOffset(m_state.shadowOffset.width(), m_state.shadowOffset.height());
+            p->translate(shadowOffset);
+            p->fillPath(platformPath, QColor(m_state.shadowColor));
+            p->translate(-shadowOffset);
+        }
+    }
+
+    p->fillPath(platformPath, QColor(color));
+}
+
 bool GraphicsContext::isInTransparencyLayer() const
 {
     return m_data->layerCount;
@@ -821,10 +852,10 @@ IntRect GraphicsContext::clipBounds() const
     QPainter* p = m_data->p();
     QRectF clipRect;
 
+    clipRect = p->transform().inverted().mapRect(p->window());
+
     if (p->hasClipping())
-        clipRect = m_data->clipBoundingRect();
-    else
-        clipRect = p->transform().inverted().mapRect(p->window());
+        clipRect = clipRect.intersected(m_data->clipBoundingRect());
 
     return enclosingIntRect(clipRect);
 }
