@@ -78,14 +78,10 @@ void QWebViewPrivate::_q_pageDestroyed()
 
     \inmodule QtWebKit
 
-    QWebView is the main widget component of the QtWebKit web browsing module.
+    QWebView is the main widget component of the Qt WebKit web browsing module.
     It can be used in various applications to display web content live from the
     Internet.
 
-    The image below shows QWebView previewed in \QD with a Nokia website.
-
-    \image qwebview-url.png
-
     A web site can be loaded onto QWebView with the load() function. Like all
     Qt widgets, the show() function must be invoked in order to display
     QWebView. The snippet below illustrates this:
@@ -144,7 +140,7 @@ void QWebViewPrivate::_q_pageDestroyed()
     \image qwebview-diagram.png
 
     \note It is possible to use QWebPage and QWebFrame, without using QWebView,
-    if you do not require QWidget attributes. Nevertheless, QtWebKit depends
+    if you do not require QWidget attributes. Nevertheless, Qt WebKit depends
     on QtGui, so you should use a QApplication instead of QCoreApplication.
 
     \sa {Previewer Example}, {Web Browser}, {Form Extractor Example},
